# deqar-tools
Collections of additional scripts to manage DEQAR data

## deqar.py
Module to work with DEQAR APIs

## importInstitutions.py
Imports lists of higher education institutions, provided in CSV, using the DEQAR Admin API

## deqar-get, deqar-head, deqar-submit
Simple shell script wrappers to make requests to DEQAR APIs using [curl](https://curl.haxx.se/)

## deqar-cli.py
Simple CLI to search and browse institutions with reports - incomplete, just written for testing the module

## test-pw.pl
Perl script to test whether users still have a default password set
